@@ -1,16 +1,21 @@
 #!/bin/sh
 #
+#__>> Keep in sync with ~/R/Pkgs/Matrix/po/update-me.sh  <<__
+#
 ## Script for updating package-specific *.pot files
 ## written such that it should work for any package
 #
+R=${R:-R}
 thisdir=`dirname $0` ; cd $thisdir; thisdir=`pwd`
 echo 'preliminary thisdir='$thisdir
 pkgDIR=`dirname $thisdir`
 pkg=`basename $pkgDIR`
 echo '  -->        pkgDIR='$pkgDIR' ; pkg='$pkg
-echo ''; echo '## FIXME ## use new Scheme from R 2.16.x on'
-cd `R-patched RHOME`/po
-make pkg-update PKG=$pkg PKGDIR=$pkgDIR
+# echo ''; echo '## FIXME ## use new Scheme from R 3.0.x on'
+# cd `$R RHOME`/po
+# make pkg-update PKG=$pkg PKGDIR=$pkgDIR
+echo "require('tools'); update_pkg_po('$pkgDIR')" | $R --slave
+##    --------------------------------  as of R 3.0.0
 echo 'end{make pkg-update}' ; echo ''
 echo 'Test with (e.g.)'
 echo '       LANGUAGE=de R --no-environ --no-save' ; echo ''
